@@ -185,7 +185,7 @@ class BrokerConnection(object):
         return self
 
     def ensure(self, obj, fun, errback=None, max_retries=None,
-            interval_start=1, interval_step=1, interval_max=1):
+            interval_start=1, interval_step=1, interval_max=1, on_revive=None):
         """Ensure operation completes, regardless of any channel/connection
         errors occuring.
 
@@ -244,12 +244,55 @@ class BrokerConnection(object):
                                            interval_start,
                                            interval_step,
                                            interval_max)
-                    obj.revive(self.channel())
+                    new_channel = self.channel()
+                    obj.revive(new_channel)
+                    if on_revive:
+                        on_revive(new_channel)
                     got_connection += 1
 
         _insured.func_name = _insured.__name__ = "%s(insured)" % fun.__name__
         return _insured
 
+    def autoretry(self, fun, channel=None, **ensure_options):
+        """Decorator for functions supporting a ``channel`` keyword argument.
+
+        The resulting callable will retry calling the function if
+        it raises connection or channel related errors.
+        The return value will be a tuple of ``(retval, last_created_channel)``.
+
+        If a ``channel`` is not provided, then one will be automatically
+        acquired (remember to close it afterwards).
+
+        See :meth:`ensure` for the full list of supported keyword arguments.
+
+        Example usage::
+
+            channel = connection.channel()
+            try:
+                ret, channel = connection.autoretry(publish_messages, channel)
+            finally:
+                channel.close()
+        """
+        channels = [channel]
+        create_channel = self.channel
+
+        class Revival(object):
+            __name__ = fun.__name__
+            __module__ = fun.__module__
+            __doc__ = fun.__doc__
+
+            def revive(self, channel):
+                channels[0] = channel
+
+            def __call__(self, *args, **kwargs):
+                if channels[0] is None:
+                    self.revive(create_channel())
+                kwargs["channel"] = channels[0]
+                return fun(*args, **kwargs), channels[0]
+
+        revive = Revival()
+        return self.ensure(revive, revive, **ensure_options)
+
     def create_transport(self):
         return self.get_transport_cls()(client=self)
     create_backend = create_transport   # FIXME
@@ -616,7 +659,6 @@ class ConnectionPool(Resource):
 
     def prepare(self, resource):
         resource._debug("acquired")
-        resource.connect()
         return resource
 
 
