@@ -138,6 +138,15 @@ class Producer(object):
         self.channel = channel
         self.exchange.revive(channel)
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, *exc_info):
+        self.close()
+
+    def close(self):
+        pass
+
     def _prepare(self, body, serializer=None,
             content_type=None, content_encoding=None, compression=None,
             headers=None):
@@ -261,6 +270,13 @@ class Consumer(object):
     def __exit__(self, *exc_info):
         self.cancel()
 
+    def add_queue(self, queue):
+        queue = queue(self.channel)
+        if self.auto_declare:
+            queue.declare()
+        self.queues.append(queue)
+        return queue
+
     def consume(self, no_ack=None):
         """Register consumer on server.
 
@@ -290,8 +306,15 @@ class Consumer(object):
         except KeyError:
             pass
         else:
+            self.queues[:] = [q for q in self.queues if q.name != queue]
             self.channel.basic_cancel(tag)
 
+    def consuming_from(self, queue):
+        name = queue
+        if isinstance(queue, Queue):
+            name = queue.name
+        return any(q.name == name for q in self.queues)
+
     def purge(self):
         """Purge messages from all queues.
 
