@@ -1,16 +1,16 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-import cPickle as pickle
 import sys
-import unittest2 as unittest
 
 from nose import SkipTest
 
 from kombu.serialization import registry, register, SerializerNotInstalled, \
                                 raw_encode, register_yaml, register_msgpack, \
-                                decode
+                                decode, bytes_type, pickle, \
+                                unregister, register_pickle
 
+from kombu.tests.utils import unittest
 from kombu.tests.utils import mask_modules
 
 # For content_encoding tests
@@ -80,7 +80,7 @@ class test_Serialization(unittest.TestCase):
         self.assertIsInstance(registry.decode(unicode_string_as_utf8,
                                               content_type='application/data',
                                               content_encoding='binary'),
-                              str)
+                              bytes_type)
 
         self.assertEquals(unicode_string_as_utf8,
                           registry.decode(
@@ -195,6 +195,15 @@ class test_Serialization(unittest.TestCase):
     def test_register(self):
         register(None, None, None, None)
 
+    def test_unregister(self):
+        self.assertRaises(SerializerNotInstalled,
+                          unregister, "nonexisting")
+        registry.encode("foo", serializer="pickle")
+        unregister("pickle")
+        self.assertRaises(SerializerNotInstalled,
+                          registry.encode, "foo", serializer="pickle")
+        register_pickle()
+
     def test_set_default_serializer_missing(self):
         self.assertRaises(SerializerNotInstalled,
                           registry._set_default_serializer, "nonexisting")
@@ -204,8 +213,9 @@ class test_Serialization(unittest.TestCase):
                           registry.encode, "foo", serializer="nonexisting")
 
     def test_raw_encode(self):
-        self.assertTupleEqual(raw_encode(str("foo")),
-                              ("application/data", "binary", "foo"))
+        self.assertTupleEqual(raw_encode("foo".encode("utf-8")),
+                              ("application/data", "binary",
+                                  "foo".encode("utf-8")))
 
     @mask_modules("yaml")
     def test_register_yaml__no_yaml(self):
