@@ -17,6 +17,7 @@ ACKNOWLEDGED_STATES = frozenset(["ACK", "REJECTED", "REQUEUED"])
 
 
 class StdChannel(object):
+    no_ack_consumers = None
 
     def Consumer(self, *args, **kwargs):
         from kombu.messaging import Consumer
@@ -30,6 +31,11 @@ class StdChannel(object):
         raise NotImplementedError("%r does not implement list_bindings" % (
             self.__class__, ))
 
+    def after_reply_message_received(self, queue):
+        """reply queue semantics: can be used to delete the queue
+           after transient reply message received."""
+        pass
+
 
 class Message(object):
     """Base class for received messages."""
@@ -90,6 +96,10 @@ class Message(object):
             acknowledged/requeued/rejected.
 
         """
+        if self.channel.no_ack_consumers is not None:
+            consumer_tag = self.delivery_info["consumer_tag"]
+            if consumer_tag in self.channel.no_ack_consumers:
+                return
         if self.acknowledged:
             raise self.MessageStateError(
                 "Message already acknowledged with state: %s" % self._state)
@@ -181,3 +191,7 @@ class Transport(object):
 
     def verify_connection(self, connection):
         return True
+
+    @property
+    def default_connection_params(self):
+        return {}
