@@ -5,7 +5,7 @@ from uuid import UUID, uuid4 as _uuid4, _uuid_generate_random
 
 try:
     import ctypes
-except ImportError:
+except:
     ctypes = None  # noqa
 
 
@@ -67,6 +67,19 @@ def fxrange(start=1.0, stop=None, step=1.0, repeatlast=False):
             yield cur - step
 
 
+def fxrangemax(start=1.0, stop=None, step=1.0, max=100.0):
+    sum_, cur = 0, start * 1.0
+    while 1:
+        if sum_ >= max:
+            break
+        yield cur
+        if stop:
+            cur = min(cur + step, stop)
+        else:
+            cur += step
+        sum_ += cur
+
+
 def retry_over_time(fun, catch, args=[], kwargs={}, errback=None,
         max_retries=None, interval_start=2, interval_step=2, interval_max=30):
     """Retry the function over and over until max retries is exceeded.
